@@ -3,12 +3,11 @@ from __future__ import annotations
 import asyncio
 import logging
 from asyncio import Lock, TimerHandle, Transport
-from typing import Optional
 
 import async_timeout
 
 from . import DeviceData
-from .api import COMMANDS_SECURED, QUEUE_TIMEOUT, RoborockClient
+from .api import COMMANDS_SECURED, RoborockClient
 from .exceptions import CommandVacuumError, RoborockConnectionException, RoborockException
 from .protocol import MessageParser
 from .roborock_message import MessageRetry, RoborockMessage, RoborockMessageProtocol
@@ -19,10 +18,10 @@ _LOGGER = logging.getLogger(__name__)
 
 
 class RoborockLocalClient(RoborockClient, asyncio.Protocol):
-    def __init__(self, device_data: DeviceData):
+    def __init__(self, device_data: DeviceData, queue_timeout: int = 4):
         if device_data.host is None:
             raise RoborockException("Host is required")
-        super().__init__("abc", device_data)
+        super().__init__("abc", device_data, queue_timeout)
         self.host = device_data.host
         self._batch_structs: list[RoborockMessage] = []
         self._executing = False
@@ -39,7 +38,7 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
         parser_msg, self.remaining = MessageParser.parse(message, local_key=self.device_info.device.local_key)
         self.on_message_received(parser_msg)
 
-    def connection_lost(self, exc: Optional[Exception]):
+    def connection_lost(self, exc: Exception | None):
         self.sync_disconnect()
         self.on_connection_lost(exc)
 
@@ -59,8 +58,8 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
             try:
                 if not self.is_connected():
                     self.sync_disconnect()
-                    async with async_timeout.timeout(QUEUE_TIMEOUT):
-                        self._logger.info(f"Connecting to {self.host}")
+                    async with async_timeout.timeout(self.queue_timeout):
+                        self._logger.debug(f"Connecting to {self.host}")
                         self.transport, _ = await self.event_loop.create_connection(  # type: ignore
                             lambda: self, self.host, 58867
                         )
@@ -83,11 +82,13 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
         async with self._mutex:
             self.sync_disconnect()
 
-    def build_roborock_message(self, method: RoborockCommand, params: Optional[list | dict] = None) -> RoborockMessage:
+    def build_roborock_message(
+        self, method: RoborockCommand | str, params: list | dict | None = None
+    ) -> RoborockMessage:
         secured = True if method in COMMANDS_SECURED else False
         request_id, timestamp, payload = self._get_payload(method, params, secured)
         request_protocol = RoborockMessageProtocol.GENERAL_REQUEST
-        message_retry: Optional[MessageRetry] = None
+        message_retry: MessageRetry | None = None
         if method == RoborockCommand.RETRY_REQUEST and isinstance(params, dict):
             message_retry = MessageRetry(method=params["method"], retry_id=params["retry_id"])
         return RoborockMessage(
@@ -121,8 +122,8 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
 
     async def _send_command(
         self,
-        method: RoborockCommand,
-        params: Optional[list | dict] = None,
+        method: RoborockCommand | str,
+        params: list | dict | None = None,
     ):
         roborock_message = self.build_roborock_message(method, params)
         return await self.send_message(roborock_message)
